#
# Copyright 2013 Anselm Kruis
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.

"""
Installer for Stackless Python (Windows)

This distribution adds a Stackless Python executable to an existing
CPython installation.

The distribution is a normal Python-Egg. It provides two scripts: 

* *install-stackless*: installs the stackless executable besides the 
  regular CPython executable.
* *uninstall-stackless*: removes the stackless executables
  
The distribution requires the package setuptools during installation.
"""

from setuptools import setup

from slpInstaller import UCS, PLATFORM, INSTALLER_VERSION_STR, STACKLESS_VERSION


setup(
    name='stackless_installer_C%d_%s' % (UCS, PLATFORM.replace('-', '_')),
    version=INSTALLER_VERSION_STR,
    description='Installer for Stackless Python %s ucs%d' % (PLATFORM, UCS),
    author='Christian Tismer',
    author_email='tismer@stackless.com',
    maintainer='Anselm Kruis',
    maintainer_email='a.kruis@science-computing.de',
    url='http://www.stackless.com',
    packages=['slpInstaller'],
    include_package_data = True,
    # other arguments here...
    entry_points = {
        'console_scripts': [
            'install-stackless = slpInstaller:main_install',
            'uninstall-stackless = slpInstaller:main_uninstall',
        ],
    },
    zip_safe=True,
    long_description=open("README.rst").read(),
    classifiers=[
          "License :: OSI Approved :: Python Software Foundation License", # Stackless Python files
          "License :: OSI Approved :: Apache Software License", # for this installer
          "Programming Language :: Python",
          "Programming Language :: Python :: "+".".join(map(str,STACKLESS_VERSION[:2])),
          "Programming Language :: Python :: Implementation :: Stackless", 
          "Operating System :: POSIX :: Linux",
          "Development Status :: 5 - Production/Stable",
          "Intended Audience :: Developers",
          "Topic :: Software Development :: Libraries :: Python Modules",
      ],
      keywords='stackless',
      license='Python Software Foundation License (Stackless-Python), Apache License, Version 2.0 (Installer)',
      platforms=PLATFORM,
    )
